@@ -4,6 +4,7 @@ from django.forms import (
     BooleanField, PasswordInput,
 )
 
+from ipam.models import IPAddress, Prefix
 from netbox.forms import (
     NetBoxModelBulkEditForm,
     NetBoxModelFilterSetForm,
@@ -31,6 +32,12 @@ class AppEnvironmentForm(NetBoxModelForm):
         label="OCP Project",
         help_text="Choose the ocp project e.g. web shop",
     )
+    egress_ip = DynamicModelChoiceField(
+        # queryset=Prefix.get_child_ips(Prefix.objects.get(prefix='10.190.1.64/26')),
+        queryset=IPAddress.objects.filter(address__net_host_contained='10.190.1.64/26'),
+        label="Egress IP",
+        help_text="Select your egress ip",
+    )
 
     fieldsets = (
         ('OCP Project', ['ocp_project']),
